@@ -1,7 +1,7 @@
 package Galileo::Command::dump;
 use Mojo::Base 'Mojolicious::Command';
 use File::Spec;
-use Mojo::Util 'spurt';
+use Mojo::Util qw/encode spurt/;
 use Getopt::Long qw/GetOptionsFromArray/;
 
 has description => "Dump all stored pages as markdown\n";
@@ -18,6 +18,10 @@ options:
   This option accepts an sprintf format for including the title.
   As a special case, if this flag is given without argument, an h1 
   title is created.
+
+--encoding,-e
+  An encoding type. Defaults to UTF-8. Available encodings are the
+  same as Encode module of Perl.
 END
 
 sub run {
@@ -26,6 +30,7 @@ sub run {
   GetOptionsFromArray( \@_,
     'directory=s' => \my $dir,
     'title:s'     => \(my $title = '<!-- %s -->'),
+    'encoding:s'  => \(my $encoding = 'UTF-8'),
   );
 
   $title = '# %s' unless $title;
@@ -40,6 +45,7 @@ sub run {
 
     my $content = sprintf "$title\n", $page->title;
     $content .= $page->md;
+    $content = encode($encoding, $content) if $encoding;
     spurt $content, $file;
   }
 
