@@ -1,6 +1,8 @@
 package Galileo::Page;
 use Mojo::Base 'Mojolicious::Controller';
 
+use Mojo::JSON 'j';
+
 sub show {
   my $self = shift;
   my $name = $self->param('name');
@@ -35,7 +37,10 @@ sub edit {
     $self->stash( input => "Hello World" );
   }
 
-  $self->stash( sanitize => $self->config->{sanitize} // 1 );   #/# highlight fix
+  $self->stash(
+    sanitize               => $self->config->{sanitize} // 1, #/# highlight fix
+    pagedown_extra_options => j( $self->config->{pagedown_extra_options} ),
+  );
 
   $self->render;
 }
